ChartExt

Trait ChartExt 

pub trait ChartExt {
    // Required methods
    fn plot_area(&self) -> &PlotArea;
    fn legend(&self) -> Option<&Legend>;
    fn chart_types(&self) -> Vec<ChartKind>;
    fn title_text(&self) -> Option<String>;
}
Extension trait for Chart providing convenience access to chart content.

Corresponds to ECMA-376 21.2.2.27 (CT_Chart).

Required Methods

fn plot_area(&self) -> &PlotArea

The plot area containing the chart series and axes.

fn legend(&self) -> Option<&Legend>

The chart legend, if present.

fn chart_types(&self) -> Vec<ChartKind>

All chart kinds present in this chart’s plot area.

fn title_text(&self) -> Option<String>

The chart title text, if the title contains rich text content.

Implementors

Source

impl ChartExt for Chart

Available on crate feature dml-charts only.