pub struct CTAlphaCeilingEffect;Trait Implementations
Sourceimpl Clone for CTAlphaCeilingEffect
impl Clone for CTAlphaCeilingEffect
Sourcefn clone(&self) -> CTAlphaCeilingEffect
fn clone(&self) -> CTAlphaCeilingEffect
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CTAlphaCeilingEffect
impl Debug for CTAlphaCeilingEffect
Sourceimpl Default for CTAlphaCeilingEffect
impl Default for CTAlphaCeilingEffect
Sourcefn default() -> CTAlphaCeilingEffect
fn default() -> CTAlphaCeilingEffect
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CTAlphaCeilingEffect
impl<'de> Deserialize<'de> for CTAlphaCeilingEffect
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromXml for CTAlphaCeilingEffect
impl FromXml for CTAlphaCeilingEffect
Sourcefn from_xml<R: BufRead>(
reader: &mut Reader<R>,
_start: &BytesStart<'_>,
is_empty: bool,
) -> Result<Self, ParseError>
fn from_xml<R: BufRead>( reader: &mut Reader<R>, _start: &BytesStart<'_>, is_empty: bool, ) -> Result<Self, ParseError>
Parse from an XML reader positioned at the start tag. Read more
Sourceimpl Serialize for CTAlphaCeilingEffect
impl Serialize for CTAlphaCeilingEffect
Sourceimpl ToXml for CTAlphaCeilingEffect
impl ToXml for CTAlphaCeilingEffect
Sourcefn is_empty_element(&self) -> bool
fn is_empty_element(&self) -> bool
Whether this element has no children (self-closing).
Sourcefn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
fn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
Write attributes onto the start tag and return it.
Sourcefn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write child elements and text content inside the element.
Sourcefn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write a complete element:
<tag attrs>children</tag> or <tag attrs/>.Auto Trait Implementations
impl Freeze for CTAlphaCeilingEffect
impl RefUnwindSafe for CTAlphaCeilingEffect
impl Send for CTAlphaCeilingEffect
impl Sync for CTAlphaCeilingEffect
impl Unpin for CTAlphaCeilingEffect
impl UnsafeUnpin for CTAlphaCeilingEffect
impl UnwindSafe for CTAlphaCeilingEffect