pub struct CTComplementTransform;Trait Implementations
Sourceimpl Clone for CTComplementTransform
impl Clone for CTComplementTransform
Sourcefn clone(&self) -> CTComplementTransform
fn clone(&self) -> CTComplementTransform
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CTComplementTransform
impl Debug for CTComplementTransform
Sourceimpl Default for CTComplementTransform
impl Default for CTComplementTransform
Sourcefn default() -> CTComplementTransform
fn default() -> CTComplementTransform
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CTComplementTransform
impl<'de> Deserialize<'de> for CTComplementTransform
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromXml for CTComplementTransform
impl FromXml for CTComplementTransform
Sourcefn from_xml<R: BufRead>(
reader: &mut Reader<R>,
_start: &BytesStart<'_>,
is_empty: bool,
) -> Result<Self, ParseError>
fn from_xml<R: BufRead>( reader: &mut Reader<R>, _start: &BytesStart<'_>, is_empty: bool, ) -> Result<Self, ParseError>
Parse from an XML reader positioned at the start tag. Read more
Sourceimpl Serialize for CTComplementTransform
impl Serialize for CTComplementTransform
Sourceimpl ToXml for CTComplementTransform
impl ToXml for CTComplementTransform
Sourcefn is_empty_element(&self) -> bool
fn is_empty_element(&self) -> bool
Whether this element has no children (self-closing).
Sourcefn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
fn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
Write attributes onto the start tag and return it.
Sourcefn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write child elements and text content inside the element.
Sourcefn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write a complete element:
<tag attrs>children</tag> or <tag attrs/>.Auto Trait Implementations
impl Freeze for CTComplementTransform
impl RefUnwindSafe for CTComplementTransform
impl Send for CTComplementTransform
impl Sync for CTComplementTransform
impl Unpin for CTComplementTransform
impl UnsafeUnpin for CTComplementTransform
impl UnwindSafe for CTComplementTransform