pub struct CTEmptyElement;Trait Implementations
Sourceimpl Clone for CTEmptyElement
impl Clone for CTEmptyElement
Sourcefn clone(&self) -> CTEmptyElement
fn clone(&self) -> CTEmptyElement
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CTEmptyElement
impl Debug for CTEmptyElement
Sourceimpl Default for CTEmptyElement
impl Default for CTEmptyElement
Sourcefn default() -> CTEmptyElement
fn default() -> CTEmptyElement
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CTEmptyElement
impl<'de> Deserialize<'de> for CTEmptyElement
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromXml for CTEmptyElement
impl FromXml for CTEmptyElement
Sourcefn from_xml<R: BufRead>(
reader: &mut Reader<R>,
_start: &BytesStart<'_>,
is_empty: bool,
) -> Result<Self, ParseError>
fn from_xml<R: BufRead>( reader: &mut Reader<R>, _start: &BytesStart<'_>, is_empty: bool, ) -> Result<Self, ParseError>
Parse from an XML reader positioned at the start tag. Read more
Sourceimpl Serialize for CTEmptyElement
impl Serialize for CTEmptyElement
Sourceimpl ToXml for CTEmptyElement
impl ToXml for CTEmptyElement
Sourcefn is_empty_element(&self) -> bool
fn is_empty_element(&self) -> bool
Whether this element has no children (self-closing).
Sourcefn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
fn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
Write attributes onto the start tag and return it.
Sourcefn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write child elements and text content inside the element.
Sourcefn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write a complete element:
<tag attrs>children</tag> or <tag attrs/>.Auto Trait Implementations
impl Freeze for CTEmptyElement
impl RefUnwindSafe for CTEmptyElement
impl Send for CTEmptyElement
impl Sync for CTEmptyElement
impl Unpin for CTEmptyElement
impl UnsafeUnpin for CTEmptyElement
impl UnwindSafe for CTEmptyElement