pub struct CTGroupFillProperties;Trait Implementations
Sourceimpl Clone for CTGroupFillProperties
impl Clone for CTGroupFillProperties
Sourcefn clone(&self) -> CTGroupFillProperties
fn clone(&self) -> CTGroupFillProperties
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CTGroupFillProperties
impl Debug for CTGroupFillProperties
Sourceimpl Default for CTGroupFillProperties
impl Default for CTGroupFillProperties
Sourcefn default() -> CTGroupFillProperties
fn default() -> CTGroupFillProperties
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CTGroupFillProperties
impl<'de> Deserialize<'de> for CTGroupFillProperties
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromXml for CTGroupFillProperties
impl FromXml for CTGroupFillProperties
Sourcefn from_xml<R: BufRead>(
reader: &mut Reader<R>,
_start: &BytesStart<'_>,
is_empty: bool,
) -> Result<Self, ParseError>
fn from_xml<R: BufRead>( reader: &mut Reader<R>, _start: &BytesStart<'_>, is_empty: bool, ) -> Result<Self, ParseError>
Parse from an XML reader positioned at the start tag. Read more
Sourceimpl Serialize for CTGroupFillProperties
impl Serialize for CTGroupFillProperties
Sourceimpl ToXml for CTGroupFillProperties
impl ToXml for CTGroupFillProperties
Sourcefn is_empty_element(&self) -> bool
fn is_empty_element(&self) -> bool
Whether this element has no children (self-closing).
Sourcefn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
fn write_attrs<'a>(&self, start: BytesStart<'a>) -> BytesStart<'a>
Write attributes onto the start tag and return it.
Sourcefn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_children<W>(
&self,
_writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write child elements and text content inside the element.
Sourcefn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
fn write_element<W>(
&self,
tag: &str,
writer: &mut Writer<W>,
) -> Result<(), SerializeError>where
W: Write,
Write a complete element:
<tag attrs>children</tag> or <tag attrs/>.Auto Trait Implementations
impl Freeze for CTGroupFillProperties
impl RefUnwindSafe for CTGroupFillProperties
impl Send for CTGroupFillProperties
impl Sync for CTGroupFillProperties
impl Unpin for CTGroupFillProperties
impl UnsafeUnpin for CTGroupFillProperties
impl UnwindSafe for CTGroupFillProperties