pub enum ChartKind {
Show 16 variants
Bar,
Bar3D,
Line,
Line3D,
Pie,
Pie3D,
Scatter,
Area,
Area3D,
Bubble,
Doughnut,
Radar,
Stock,
Surface,
Surface3D,
OfPie,
}Expand description
The kind of chart contained in a plot area.
Corresponds to the chart element types defined in ECMA-376 21.2.
Variants
Bar
Bar or column chart (CT_BarChart).
Bar3D
3D bar chart (CT_Bar3DChart).
Line
Line chart (CT_LineChart).
Line3D
3D line chart (CT_Line3DChart).
Pie
Pie chart (CT_PieChart).
Pie3D
3D pie chart (CT_Pie3DChart).
Scatter
Scatter / XY chart (CT_ScatterChart).
Area
Area chart (CT_AreaChart).
Area3D
3D area chart (CT_Area3DChart).
Bubble
Bubble chart (CT_BubbleChart).
Doughnut
Doughnut chart (CT_DoughnutChart).
Radar
Radar / spider chart (CT_RadarChart).
Stock
Stock chart (CT_StockChart).
Surface
Surface chart (CT_SurfaceChart).
Surface3D
3D surface chart (CT_Surface3DChart).
OfPie
Pie-of-pie or bar-of-pie chart (CT_OfPieChart).