pub trait ChartExt {
// Required methods
fn plot_area(&self) -> &PlotArea;
fn legend(&self) -> Option<&Legend>;
fn chart_types(&self) -> Vec<ChartKind>;
fn title_text(&self) -> Option<String>;
}Expand description
Extension trait for Chart providing convenience access to chart content.
Corresponds to ECMA-376 21.2.2.27 (CT_Chart).
Required Methods
Sourcefn chart_types(&self) -> Vec<ChartKind>
fn chart_types(&self) -> Vec<ChartKind>
All chart kinds present in this chart’s plot area.
Sourcefn title_text(&self) -> Option<String>
fn title_text(&self) -> Option<String>
The chart title text, if the title contains rich text content.